@@ -53,11 +53,8 @@ bool convertFile(const QString &file)
 
     QFile presetFile (file);
 
-    if (! presetFile.open(IO_ReadOnly)) {
-        kDebug() << "convertFile: "
-                 << i18n("error opening preset file")
-                 << " " << file << " "
-                 << i18n("for reading") << endl;
+    if (! presetFile.open(QIODevice::ReadOnly)) {
+        kDebug() << "convertFile: error opening preset file" << file << "for reading";
         return false;
     }
 
@@ -134,11 +131,8 @@ bool convertFile(const QString &file)
     // write output
     ////////////////////////////////////////////////////////////////////////
 
-    if (! presetFile.open(IO_WriteOnly)) {
-        kDebug() << "convertFile: "
-                 << i18n("error opening preset file")
-                 << " " << file << " "
-                 << i18n("for writing") << endl;
+    if (! presetFile.open(QIODevice::WriteOnly)) {
+        kDebug() << "convertFile: error opening preset file" << file << "for writing";
        return false;
     }
 
@@ -149,11 +143,8 @@ bool convertFile(const QString &file)
     outs << xmlData;
 
     if (presetFile.error() != QFile::NoError) {
-        kDebug() << "StationList::writeXML: "
-                 << i18n("error writing preset file")
-                 << " " << file
-                 << " (" << presetFile.error() << ")"
-                 << endl;
+        kDebug() << "StationList::writeXML: error writing preset file" << file
+                 << "(" << presetFile.error() << ")";
         return false;
     }
 
