@@ -38,6 +38,7 @@
 #include "soundstreamid.h"
 #include "sound_metadata.h"
 #include "radiostation.h"
+#include "recording_template.h"
 
 #define CALL_SNDSTR_SERVER(name, param, call) \
     inline int name param const { \
@@ -137,11 +138,11 @@ SENDERS:
     // we need extra recording, in order to distinguish between plain capturing
     // (making sound data available to kradio) and writing a stream to disk  or sth similar
     IF_SENDER_FINE  (  sendStartRecording, (SoundStreamID id,
-                                            const QString &filenameTemplate = QString())          )
+                                            const recordingTemplate_t &filenameTemplate = recordingTemplate_t())          )
     IF_SENDER_FINE  (  sendStartRecordingWithFormat, (SoundStreamID id,
-                                   const SoundFormat &proposed_format,
-                                   SoundFormat       &real_format,
-                                   const QString &filenameTemplate = QString())                   )
+                                                      const SoundFormat &proposed_format,
+                                                      SoundFormat       &real_format,
+                                                      const recordingTemplate_t     &filenameTemplate = recordingTemplate_t())                   )
     IF_SENDER_FINE  (  sendStopRecording, (SoundStreamID id)                                      )
     IF_SENDER_FINE  (  queryIsRecordingRunning, (SoundStreamID id, bool &running, SoundFormat &sf))
 
@@ -278,11 +279,11 @@ RECEIVERS:
     IF_RECEIVER_EMPTY(  stopCapture(SoundStreamID /*id*/)                                                       )
     IF_RECEIVER_EMPTY(  isCaptureRunning(SoundStreamID /*id*/, bool &/*running*/, SoundFormat &/*sf*/) const    )
 
-    IF_RECEIVER_EMPTY(  startRecording(SoundStreamID /*id*/, const QString &/*filenameTemplate*/)               )
+    IF_RECEIVER_EMPTY(  startRecording(SoundStreamID /*id*/, const recordingTemplate_t & /*template*/)               )
     IF_RECEIVER_EMPTY(  startRecordingWithFormat(SoundStreamID /*id*/,
                                      const SoundFormat &/*proposed_format*/,
                                      SoundFormat       &/*real_format*/,
-                                     const QString     &/*filenameTemplate*/
+                                     const recordingTemplate_t  &/*template*/
                                      )                                                                          )
     IF_RECEIVER_EMPTY(  stopRecording(SoundStreamID /*id*/)                                                     )
     IF_RECEIVER_EMPTY(  isRecordingRunning(SoundStreamID /*id*/, bool &/*running*/, SoundFormat &/*sf*/) const  )
@@ -368,13 +369,13 @@ SENDERS:
     CALL_SNDSTR_SERVER  (  sendStopCapture, (SoundStreamID id), (id)                                                            )
     CALL_SNDSTR_SERVER  (  queryIsCaptureRunning, (SoundStreamID id, bool &b, SoundFormat &sf), (id, b, sf)                     )
 
-    CALL_SNDSTR_SERVER  (  sendStartRecording, (SoundStreamID id, const QString &filenameTemplate = QString()), (id, filenameTemplate)      )
+    CALL_SNDSTR_SERVER  (  sendStartRecording, (SoundStreamID id, const recordingTemplate_t &templ = recordingTemplate_t()), (id, templ)      )
     CALL_SNDSTR_SERVER  (  sendStartRecordingWithFormat,
                                   (SoundStreamID id,
                                    const SoundFormat &proposed_format,
                                    SoundFormat       &real_format,
-                                   const QString &filenameTemplate = QString()),
-                                  (id, proposed_format, real_format, filenameTemplate)                           )
+                                   const recordingTemplate_t &templ = recordingTemplate_t()),
+                                  (id, proposed_format, real_format, templ)                           )
     CALL_SNDSTR_SERVER  (  sendStopRecording, (SoundStreamID id), (id)                                           )
     CALL_SNDSTR_SERVER  (  queryIsRecordingRunning, (SoundStreamID id, bool &b, SoundFormat &sf), (id, b, sf)    )
 
