@@ -17,6 +17,7 @@
 
 #include <klocale.h>
 #include <kaboutdata.h>
+#include <QtCore/QFile>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/ioctl.h>
@@ -591,27 +592,9 @@ bool AlsaSoundDevice::noticeSoundStreamData(SoundStreamID id,
     }
 
     const char *buffer        = data;
-    // char       *scaled_buffer = NULL;
-    // if (m_SoftPlaybackVolumeEnabled) {
-    //     double f = m_SoftPlaybackVolumeMuted ? 0 : m_SoftPlaybackVolume * m_SoftPlaybackVolumeCorrectionFactor;
-
-    //     scaled_buffer = new char[size];
-    //     memcpy(scaled_buffer, data, size);
-
-    //     format.scaleSamples(scaled_buffer, f, size/format.frameSize());
-
-    //     buffer = scaled_buffer;
-    // }
-
     size_t n = m_PlaybackBuffer.addData(buffer, size);
     consumed_size  = (consumed_size == SIZE_T_DONT_CARE) ? n : min (consumed_size, n);
 
-
-    // if (scaled_buffer) {
-    //     delete scaled_buffer;
-    //     scaled_buffer = NULL;
-    // }
-
     return true;
 }
 
@@ -782,13 +765,13 @@ bool AlsaSoundDevice::openPlaybackDevice(const SoundFormat &format, bool reopen)
 
     setWaitForMinPlaybackBufferFill(90/*percent*/);
 
-    bool error = !openAlsaDevice(m_hPlayback, m_PlaybackFormat, m_PlaybackDeviceName.toLocal8Bit(), SND_PCM_STREAM_PLAYBACK, (m_nonBlockingPlayback ? SND_PCM_NONBLOCK : 0), m_PlaybackLatency, m_PlaybackBufferSize, m_PlaybackChunkSize);
+    bool error = !openAlsaDevice(m_hPlayback, m_PlaybackFormat, QFile::encodeName(m_PlaybackDeviceName), SND_PCM_STREAM_PLAYBACK, (m_nonBlockingPlayback ? SND_PCM_NONBLOCK : 0), m_PlaybackLatency, m_PlaybackBufferSize, m_PlaybackChunkSize);
 
     if (!error) {
 
         if (m_use_threads) {
             if (m_playbackThread) {
-                logError(i18n("AlsaPlugin: internal error. Expected non-existing playback thread, but found one\n"));
+                logError(i18n("AlsaPlugin: internal error. Expected non-existing playback thread, but found one"));
                 m_playbackThread->setDone();
                 if (!m_playbackThread->wait(1000)) {
                     m_playbackThread->terminate();
@@ -846,13 +829,13 @@ bool AlsaSoundDevice::openCaptureDevice(const SoundFormat &format, bool reopen)
         m_CaptureFormat = m_CaptureFormatOverride;
     }
 
-    bool error = !openAlsaDevice(m_hCapture, m_CaptureFormat, m_CaptureDeviceName.toLocal8Bit(), SND_PCM_STREAM_CAPTURE, (m_nonBlockingCapture ? SND_PCM_NONBLOCK : 0), m_CaptureLatency, m_CaptureBufferSize, m_CaptureChunkSize);
+    bool error = !openAlsaDevice(m_hCapture, m_CaptureFormat, QFile::encodeName(m_CaptureDeviceName), SND_PCM_STREAM_CAPTURE, (m_nonBlockingCapture ? SND_PCM_NONBLOCK : 0), m_CaptureLatency, m_CaptureBufferSize, m_CaptureChunkSize);
 
     if (!error) {
 
         if (m_use_threads) {
             if (m_captureThread) {
-                logError(i18n("AlsaPlugin: internal error. Expected non-existing capture thread, but found one\n"));
+                logError(i18n("AlsaPlugin: internal error. Expected non-existing capture thread, but found one"));
                 m_captureThread->setDone();
                 if (!m_captureThread->wait(1000)) {
                     m_captureThread->terminate();
@@ -877,13 +860,14 @@ bool AlsaSoundDevice::openCaptureDevice(const SoundFormat &format, bool reopen)
 }
 
 
-bool AlsaSoundDevice::openAlsaDevice(snd_pcm_t *&alsa_handle, SoundFormat &format, const char *pcm_name, snd_pcm_stream_t stream, int flags, unsigned &latency, size_t buffer_size, size_t chunk_size)
+bool AlsaSoundDevice::openAlsaDevice(snd_pcm_t *&alsa_handle, SoundFormat &format, const QByteArray &pcm_name_ba, snd_pcm_stream_t stream, int flags, unsigned &latency, size_t buffer_size, size_t chunk_size)
 {
     bool                 error    = false;
     int                  dir      = 0;
     snd_output_t        *log      = NULL;
     snd_pcm_hw_params_t *hwparams = NULL;
     snd_pcm_sw_params_t *swparams = NULL;
+    const char          *pcm_name = pcm_name_ba.constData();
 
     snd_pcm_hw_params_alloca(&hwparams); // allocate on stack, needs no free
     snd_pcm_sw_params_alloca(&swparams); // allocate on stack, needs no free
@@ -1382,51 +1366,50 @@ void AlsaSoundDevice::checkMixerVolume(SoundStreamID id)
 
 float AlsaSoundDevice::readPlaybackMixerVolume(const QString &channel, bool &muted) const
 {
-    if (!m_hPlaybackMixer)
-        return 0; // without error
-
+    // do we have soft playback volume? 
+    // ... Then we do not need to query any device below
+    if (m_SoftPlaybackVolumeEnabled                        &&
+        m_PlaybackStreamID.isValid()                       &&
+        m_PlaybackStreams.contains(m_PlaybackStreamID)     &&
+        m_PlaybackStreams[m_PlaybackStreamID].m_ActiveMode &&
+        m_PlaybackStreams[m_PlaybackStreamID].m_Channel == channel)
+    {
+        muted = m_SoftPlaybackVolumeMuted;
+        return m_SoftPlaybackVolume;
+    }
+    
     if (m_PlaybackChannels2ID.contains(channel) && m_hPlaybackMixer) {
         AlsaMixerElement  sid  = m_PlaybackChannels2ID[channel];
         snd_mixer_elem_t *elem = snd_mixer_find_selem(m_hPlaybackMixer, sid);
         if (elem) {
-            if (m_SoftPlaybackVolumeEnabled                        &&
-                m_PlaybackStreamID.isValid()                       &&
-                m_PlaybackStreams.contains(m_PlaybackStreamID)     &&
-                m_PlaybackStreams[m_PlaybackStreamID].m_ActiveMode &&
-                m_PlaybackStreams[m_PlaybackStreamID].m_Channel == channel)
-            {
-                muted = m_SoftPlaybackVolumeMuted;
-                return m_SoftPlaybackVolume;
-            } else {
-                long min = 0;
-                long max = 0;
-                snd_mixer_selem_get_playback_volume_range(elem, &min, &max);
-                if (min != max) {
-                    long val = min;
+            long min = 0;
+            long max = 0;
+            snd_mixer_selem_get_playback_volume_range(elem, &min, &max);
+            if (min != max) {
+                long val = min;
 
-                    muted = false;
-                    int m = false;
-                    if (snd_mixer_selem_get_playback_switch(elem, SND_MIXER_SCHN_FRONT_LEFT, &m) == 0) {
-                        muted = !m;
-                    }
-                    if (snd_mixer_selem_get_playback_volume(elem, SND_MIXER_SCHN_FRONT_LEFT, &val) == 0) {
-                        return ((float)(val - min)) / (float)(max - min);
-                    }
+                muted = false;
+                int m = false;
+                if (snd_mixer_selem_get_playback_switch(elem, SND_MIXER_SCHN_FRONT_LEFT, &m) == 0) {
+                    muted = !m;
+                }
+                if (snd_mixer_selem_get_playback_volume(elem, SND_MIXER_SCHN_FRONT_LEFT, &val) == 0) {
+                    return ((float)(val - min)) / (float)(max - min);
                 }
             }
         }
+        // if we end up here, we have entered some mixer element but alsa either didn't 
+        // find it or we could not successfully query the mixer status.
+        logError("AlsaSound::readPlaybackMixerVolume: " +
+                 i18n("error while reading volume from %1, channel %2", m_PlaybackMixerName, channel));
     }
-    logError("AlsaSound::readPlaybackMixerVolume: " +
-             i18n("error while reading volume from %1, channel %2", m_PlaybackMixerName, channel));
+    // silently fail here in case we do not have any mixer element
     return 0;
 }
 
 
 float AlsaSoundDevice::readCaptureMixerVolume(const QString &channel) const
 {
-    if (!m_hCaptureMixer)
-        return 0; // without error
-
     if (m_CaptureChannels2ID.contains(channel) && m_hCaptureMixer) {
         AlsaMixerElement sid = m_CaptureChannels2ID[channel];
         snd_mixer_elem_t *elem = snd_mixer_find_selem(m_hCaptureMixer, sid);
@@ -1443,9 +1426,12 @@ float AlsaSoundDevice::readCaptureMixerVolume(const QString &channel) const
                 }
             }
         }
+        // if we end up here, we have entered some mixer element but alsa either didn't 
+        // find it or we could not successfully query the mixer status.
+        logError("AlsaSound::readCaptureMixerVolume: " +
+                i18n("error while reading volume from %1, channel %2", m_CaptureMixerName, channel));
     }
-    logError("AlsaSound::readCaptureMixerVolume: " +
-             i18n("error while reading volume from %1, channel %2", m_CaptureMixerName, channel));
+    // silently fail here in case we do not have any mixer element
     return 0;
 }
 
@@ -1455,39 +1441,42 @@ bool AlsaSoundDevice::writePlaybackMixerVolume (const QString &channel, float &v
     if (vol > 1.0) vol = 1.0;
     if (vol < 0) vol = 0.0;
 
-    if (!m_hPlaybackMixer)
-        return false;
-
+    // do we have soft playback volume? 
+    // ... Then we do not need to write any device below
+    if (m_SoftPlaybackVolumeEnabled                        &&
+        m_PlaybackStreamID.isValid()                       &&
+        m_PlaybackStreams.contains(m_PlaybackStreamID)     &&
+        m_PlaybackStreams[m_PlaybackStreamID].m_ActiveMode &&
+        m_PlaybackStreams[m_PlaybackStreamID].m_Channel == channel)
+    {
+        m_SoftPlaybackVolume = vol;
+        m_SoftPlaybackVolumeMuted   = muted;
+        return true;
+    }
+    
     if (m_PlaybackChannels2ID.contains(channel) && m_hPlaybackMixer) {
         AlsaMixerElement sid = m_PlaybackChannels2ID[channel];
         snd_mixer_elem_t *elem = snd_mixer_find_selem(m_hPlaybackMixer, sid);
         if (elem) {
-            if (m_SoftPlaybackVolumeEnabled                        &&
-                m_PlaybackStreamID.isValid()                       &&
-                m_PlaybackStreams.contains(m_PlaybackStreamID)     &&
-                m_PlaybackStreams[m_PlaybackStreamID].m_ActiveMode &&
-                m_PlaybackStreams[m_PlaybackStreamID].m_Channel == channel)
-            {
-                m_SoftPlaybackVolume = vol;
-                m_SoftPlaybackVolumeMuted   = muted;
-                return true;
-            } else {
-                long min = 0;
-                long max = 0;
-                snd_mixer_selem_get_playback_volume_range(elem, &min, &max);
-                if (min != max) {
-                    long val = (int)rint(min + (max - min) * vol);
-                    vol = (float)(val - min) / (float)(max - min);
-                    snd_mixer_selem_set_playback_switch_all(elem, !muted);
-                    if (snd_mixer_selem_set_playback_volume_all(elem, val)    == 0) {
-                        return true;
-                    }
+            long min = 0;
+            long max = 0;
+            snd_mixer_selem_get_playback_volume_range(elem, &min, &max);
+            if (min != max) {
+                long val = (int)rint(min + (max - min) * vol);
+                vol = (float)(val - min) / (float)(max - min);
+                snd_mixer_selem_set_playback_switch_all(elem, !muted);
+                if (snd_mixer_selem_set_playback_volume_all(elem, val)    == 0) {
+                    return true;
                 }
             }
         }
+        // if we end up here, we have entered some mixer element but alsa either didn't 
+        // find it or we could not successfully query the mixer status.
+        logError("AlsaSound::writePlaybackMixerVolume: " +
+        i18n("error while writing volume %1 to %2, channel %3", vol, m_PlaybackMixerName, channel));
+        return false;
     }
-    logError("AlsaSound::writePlaybackMixerVolume: " +
-    i18n("error while writing volume %1 to %2, channel %3", vol, m_PlaybackMixerName, channel));
+    // silently fail here in case we do not have any mixer element
     return false;
 }
 
@@ -1499,9 +1488,6 @@ bool AlsaSoundDevice::writeCaptureMixerVolume (const QString &channel, float &vo
     if (vol > 1.0) vol = 1.0;
     if (vol < 0) vol = 0.0;
 
-    if (!m_hCaptureMixer)
-        return false;
-
     if (m_CaptureChannels2ID.contains(channel) && m_hCaptureMixer) {
         AlsaMixerElement sid = m_CaptureChannels2ID[channel];
         snd_mixer_elem_t *elem = snd_mixer_find_selem(m_hCaptureMixer, sid);
@@ -1517,18 +1503,19 @@ bool AlsaSoundDevice::writeCaptureMixerVolume (const QString &channel, float &vo
                 }
             }
         }
+        // if we end up here, we have entered some mixer element but alsa either didn't 
+        // find it or we could not successfully query the mixer status.
+        logError("AlsaSound::writeCaptureMixerVolume: " +
+                i18n("error while writing volume %1 to %2, channel %3", vol, m_CaptureMixerName, channel));
+        return false;
     }
-    logError("AlsaSound::writeCaptureMixerVolume: " +
-             i18n("error while writing volume %1 to %2, channel %3", vol, m_CaptureMixerName, channel));
+    // silently fail here in case we do not have any mixer element
     return false;
 }
 
 
 bool AlsaSoundDevice::writeCaptureMixerSwitch (const QString &channel, bool capture)
 {
-    if (!m_hCaptureMixer)
-        return false;
-
     if (m_CaptureChannelsSwitch2ID.contains(channel) && m_hCaptureMixer) {
         AlsaMixerElement sid = m_CaptureChannelsSwitch2ID[channel];
         snd_mixer_elem_t *elem = snd_mixer_find_selem(m_hCaptureMixer, sid);
@@ -1537,9 +1524,9 @@ bool AlsaSoundDevice::writeCaptureMixerSwitch (const QString &channel, bool capt
                 return true;
             }
         }
+        logError("AlsaSound::writeCaptureMixerSwitch: " +
+                i18n("error while setting capture switch %1 for %2", channel, m_CaptureMixerName));
     }
-    logError("AlsaSound::writeCaptureMixerSwitch: " +
-             i18n("error while setting capture switch %1 for %2", channel, m_CaptureMixerName));
     return false;
 }
 
