@@ -22,6 +22,8 @@
 #include <math.h>
 #include <unistd.h>
 
+#include <QtCore/QFile>
+
 #include <kio/jobclasses.h>
 #include <kio/netaccess.h>
 #include <kio/job.h>
@@ -33,8 +35,9 @@
 
 #include "libav-global.h"
 extern "C" {
-  #include "libavformat/avio.h"
-  #include "libavformat/avformat.h"
+  #include <libavformat/avio.h>
+  #include <libavformat/avformat.h>
+  #include <libavutil/opt.h>
 }
 
 
@@ -65,6 +68,9 @@ InternetRadioDecoder::InternetRadioDecoder(QObject                    *event_par
 #if  LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(53, 42, 0) // checked: avcodec_decode_audio4 in ffmpeg >= 0.9
     m_decoded_frame       (NULL),
 #endif
+#if defined(HAVE_LIBAVRESAMPLE) || defined (HAVE_LIBSWRESAMPLE)
+    m_resample_context    (NULL),
+#endif
 
 #ifdef INET_RADIO_STREAM_HANDLING_BY_DECODER_THREAD
     m_is_mms_stream (false),
@@ -137,7 +143,7 @@ void InternetRadioDecoder::selectStreamFromPlaylist()
             openAVStream(m_playURL.pathOrUrl(), true);
         }
         if (!m_decoderOpened) {
-            log(ThreadLogging::LogWarning, i18n("failed to open %1. Trying next stream in play list.", m_playURL.pathOrUrl()));
+            log(ThreadLogging::LogWarning, i18n("Failed to open %1. Trying next stream in play list.", m_playURL.pathOrUrl()));
         }
     }
     if (!m_decoderOpened) {
@@ -170,21 +176,51 @@ bool InternetRadioDecoder::decodePacket(AVPacket &pkt, int &processed_input_byte
 #endif
 
 #if  LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(53, 42, 0) // checked: avcodec_decode_audio4 in ffmpeg >= 0.9
+#if  LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(55, 28, 1) // libav commit: https://gitorious.org/libav/libav/commit/d7b3ee9a3a03ab88d61a5895fbdbc6689f4dd671
+    av_frame_unref(m_decoded_frame);
+#else
     avcodec_get_frame_defaults(m_decoded_frame);
+#endif
     processed_input_bytes = avcodec_decode_audio4(m_av_aCodecCtx,
                                                   m_decoded_frame,
                                                   &got_frame,
                                                   &pkt);
 
+#if defined(HAVE_LIBAVRESAMPLE) || defined (HAVE_LIBSWRESAMPLE)
+    DECLARE_ALIGNED(32, uint8_t, tmp_resample_output_buffer)[m_decoded_frame->nb_samples * m_soundFormat.frameSize() + 64];
+#endif
     if (processed_input_bytes > 0 && got_frame) {
         /* if a frame has been decoded, output it */
-        generated_output_bytes = av_samples_get_buffer_size(NULL,
-                                                      m_av_aCodecCtx->channels,
-                                                      m_decoded_frame->nb_samples,
-                                                      m_av_aCodecCtx->sample_fmt,
-                                                      1
-                                                     );
+        int lineSize = 0;
+        generated_output_bytes = av_samples_get_buffer_size(&lineSize,
+                                                             m_av_aCodecCtx->channels,
+                                                             m_decoded_frame->nb_samples,
+                                                             m_av_aCodecCtx->sample_fmt,
+                                                             0
+                                                           );
         output_buf = (char*)m_decoded_frame->data[0];
+
+#if defined(HAVE_LIBAVRESAMPLE) || defined (HAVE_LIBSWRESAMPLE)
+        uint8_t *tmpBuf[2]        = { tmp_resample_output_buffer, NULL };
+        int      resampleLineSize = sizeof(tmp_resample_output_buffer) / m_soundFormat.m_Channels;
+        #ifdef HAVE_LIBAVRESAMPLE
+            int ret = avresample_convert(m_resample_context, 
+                                         tmpBuf, resampleLineSize, m_decoded_frame->nb_samples, 
+                                         m_decoded_frame->extended_data, lineSize, m_decoded_frame->nb_samples
+                                        );
+        #elif  defined (HAVE_LIBSWRESAMPLE)
+            int ret = swr_convert       (m_resample_context, 
+                                         tmpBuf, m_decoded_frame->nb_samples, 
+                                         (const uint8_t**)m_decoded_frame->extended_data, m_decoded_frame->nb_samples
+                                        );
+        #endif
+        if (ret < 0) {
+            processed_input_bytes = 0;
+            got_frame             = 0;
+        }
+        output_buf = (char*)tmp_resample_output_buffer;
+        generated_output_bytes = ret * m_soundFormat.frameSize();
+#endif
     }
 
 #elif  LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(52, 72, 2) // checked: avcodec_decode_audio3 in ffmpeg >= 0.6
@@ -227,13 +263,13 @@ bool InternetRadioDecoder::decodePacket(AVPacket &pkt, int &processed_input_byte
 
     if (processed_input_bytes < 0) {
         /* if error, skip frame */
-        log(ThreadLogging::LogWarning, i18n("%1: error decoding packet. Discarding packet")
+        log(ThreadLogging::LogWarning, i18n("%1: error decoding packet. Discarding packet",
 #ifdef INET_RADIO_STREAM_HANDLING_BY_DECODER_THREAD
-                         .arg(m_playURL.pathOrUrl())
+                         m_playURL.pathOrUrl()
 #else
-                         .arg(m_inputUrl.pathOrUrl())
+                         m_inputUrl.pathOrUrl()
 #endif
-                        );
+                        ));
         return false;
     }
     else if (generated_output_bytes > 0) {
@@ -316,7 +352,11 @@ void InternetRadioDecoder::run()
         AVPacket    pkt;
 
 #if  LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(53, 42, 0) // checked: avcodec_decode_audio4 in ffmpeg >= 0.9
+#if  LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(55, 28, 1) // libav commit: https://gitorious.org/libav/libav/commit/d7b3ee9a3a03ab88d61a5895fbdbc6689f4dd671
+        m_decoded_frame = av_frame_alloc();
+#else
         m_decoded_frame = avcodec_alloc_frame();
+#endif
         if (!m_decoded_frame) {
             m_error = true;
             log(ThreadLogging::LogError, i18n("Failed allocating AVFrame."));
@@ -591,10 +631,10 @@ void InternetRadioDecoder::open_av_input(AVInputFormat *iformat, const QString &
 
     if (err != 0) {
         if (warningsNotErrors) {
-            log(ThreadLogging::LogWarning, i18n("Could not open Stream %1").arg(stream)); //m_inputUrl.pathOrUrl()));
+            log(ThreadLogging::LogWarning, i18n("Could not open stream %1", stream)); //m_inputUrl.pathOrUrl()));
         } else {
             m_error = true;
-            log(ThreadLogging::LogError, i18n("Could not open Stream %1").arg(m_inputUrl.pathOrUrl()));
+            log(ThreadLogging::LogError, i18n("Could not open stream %1", m_inputUrl.pathOrUrl()));
         }
         closeAVStream();
     } else {
@@ -611,9 +651,9 @@ void InternetRadioDecoder::open_av_input(AVInputFormat *iformat, const QString &
 AVInputFormat *InternetRadioDecoder::getInputFormat(const QString &fallbackFormat, bool warningsNotErrors)
 {
     LibAVGlobal::ensureInitDone();
-    AVInputFormat   *iformat      = av_find_input_format(m_RadioStation.decoderClass().toLocal8Bit());
+    AVInputFormat   *iformat      = av_find_input_format(m_RadioStation.decoderClass().toLatin1());
     if (!iformat) {
-        QString decoderClass;
+        QByteArray decoderClass;
         if (m_contentType == "audio/mpeg") {
             decoderClass = "mp3";
         } else if (m_contentType == "audio/x-mpeg") {
@@ -644,9 +684,9 @@ AVInputFormat *InternetRadioDecoder::getInputFormat(const QString &fallbackForma
             decoderClass = "asf";
         }
         if (decoderClass.length()) {
-            iformat = av_find_input_format(decoderClass.toLocal8Bit());
+            iformat = av_find_input_format(decoderClass.constData());
             if (iformat) {
-                log(ThreadLogging::LogDebug, QString("found content-type = \"%1\": skipping auto detection and setting decoder class to \"%2\"").arg(m_contentType).arg(decoderClass));
+                log(ThreadLogging::LogDebug, QString("found content-type = \"%1\": skipping auto detection and setting decoder class to \"%2\"").arg(m_contentType).arg(decoderClass.constData()));
             }
         }
     }
@@ -663,17 +703,23 @@ AVInputFormat *InternetRadioDecoder::getInputFormat(const QString &fallbackForma
 //         printf("probe data size = %i\n", probeData.size());
 
         if (!err) {
-            AVProbeData pd = { m_inputUrl.pathOrUrl().toLocal8Bit(), (unsigned char*)probeData.data(), probeData.size() };
+            const QByteArray path = QFile::encodeName(m_inputUrl.pathOrUrl());
+            
+#if  (LIBAVFORMAT_VERSION_MAJOR > 55) // ffmpeg commit 5482780a3b6ef0a8934cf29aa7e2f1ef7ccb701e
+            AVProbeData pd = { path.constData(), (unsigned char*)probeData.data(), probeData.size(), NULL };
+#else
+            AVProbeData pd = { path.constData(), (unsigned char*)probeData.data(), probeData.size()       };
+#endif
 
             iformat = av_probe_input_format2(&pd, 1, &score);
         }
 
         if (!iformat) {
             if (warningsNotErrors) {
-                log(ThreadLogging::LogWarning, i18n("Autodetect of stream type failed for %1").arg(m_inputUrl.pathOrUrl()));
+                log(ThreadLogging::LogWarning, i18n("Autodetect of stream type failed for %1", m_inputUrl.pathOrUrl()));
             } else {
                 m_error = true;
-                log(ThreadLogging::LogError, i18n("Autodetect of stream type failed for %1").arg(m_inputUrl.pathOrUrl()));
+                log(ThreadLogging::LogError, i18n("Autodetect of stream type failed for %1", m_inputUrl.pathOrUrl()));
             }
             closeAVStream();
         } else {
@@ -684,7 +730,7 @@ AVInputFormat *InternetRadioDecoder::getInputFormat(const QString &fallbackForma
 #endif
 
     if (!iformat && fallbackFormat.length()) {
-        iformat = av_find_input_format(fallbackFormat.toLocal8Bit());
+        iformat = av_find_input_format(fallbackFormat.toLatin1());
     }
 
     return iformat;
@@ -703,10 +749,10 @@ bool InternetRadioDecoder::retrieveStreamInformation(const QString &stream, bool
 #endif
     if (err < 0) {
         if (warningsNotErrors) {
-            log(ThreadLogging::LogWarning, i18n("Could not find stream information in %1").arg(stream));
+            log(ThreadLogging::LogWarning, i18n("Could not find stream information in %1", stream));
         } else {
             m_error = true;
-            log(ThreadLogging::LogError, i18n("Could not find stream information in %1").arg(stream));
+            log(ThreadLogging::LogError, i18n("Could not find stream information in %1", stream));
         }
         closeAVStream();
         return false; // Couldn't find stream information
@@ -771,16 +817,16 @@ bool InternetRadioDecoder::retrieveStreamInformation(const QString &stream, bool
 
     if (m_av_audioStream == -1) {
         if (warningsNotErrors) {
-            log(ThreadLogging::LogWarning, i18n("Could not find an audio stream in %1").arg(stream));
+            log(ThreadLogging::LogWarning, i18n("Could not find an audio stream in %1", stream));
         } else {
             m_error = true;
-            log(ThreadLogging::LogError, i18n("Could not find an audio stream in %1").arg(stream));
+            log(ThreadLogging::LogError, i18n("Could not find an audio stream in %1", stream));
         }
         closeAVStream();
         return false;
     }
     updateSoundFormat();
-    return true;
+    return m_av_pFormatCtx_opened;
 }
 
 
@@ -794,10 +840,10 @@ bool InternetRadioDecoder::openCodec(const QString &stream, bool warningsNotErro
     }
     if (!m_av_aCodec) {
         if (warningsNotErrors) {
-            log(ThreadLogging::LogWarning, i18n("Could not find a codec for %1").arg(stream));
+            log(ThreadLogging::LogWarning, i18n("Could not find a codec for %1", stream));
         } else {
             m_error = true;
-            log(ThreadLogging::LogError,   i18n("Could not find a codec for %1").arg(stream));
+            log(ThreadLogging::LogError,   i18n("Could not find a codec for %1", stream));
         }
         closeAVStream();
         return false;
@@ -812,14 +858,59 @@ bool InternetRadioDecoder::openCodec(const QString &stream, bool warningsNotErro
 #endif
     if (err < 0) {
         if (warningsNotErrors) {
-            log(ThreadLogging::LogWarning, i18n("Opening codec for %1 failed").arg(stream));
+            log(ThreadLogging::LogWarning, i18n("Opening codec for %1 failed", stream));
         } else {
             m_error = true;
-            log(ThreadLogging::LogError, i18n("Opening codec for %1 failed").arg(stream));
+            log(ThreadLogging::LogError, i18n("Opening codec for %1 failed", stream));
         }
         closeAVStream();
         return false;
     }
+    
+    
+#if defined(HAVE_LIBAVRESAMPLE) || defined (HAVE_LIBSWRESAMPLE)
+    // Set up SWR context once you've got codec information
+#ifdef HAVE_LIBAVRESAMPLE
+    m_resample_context = avresample_alloc_context();
+#elif defined HAVE_LIBSWRESAMPLE
+    m_resample_context = swr_alloc();
+#endif
+    uint64_t chLayout = m_av_aCodecCtx->channel_layout;
+    if (!chLayout) {
+        switch(m_av_pFormatCtx->streams[m_av_audioStream]->codec->channels) {
+            case 1:
+                chLayout = AV_CH_LAYOUT_MONO;
+                break;
+            case 2:
+                chLayout = AV_CH_LAYOUT_STEREO;
+                break;
+            default:
+                m_error = true;
+                log(ThreadLogging::LogError, i18n("Unknown channel layout for %1", stream));
+                closeAVStream();
+                break;
+        }
+    }
+    if (!m_error) {
+        av_opt_set_int       (m_resample_context, "in_channel_layout",  chLayout,                       0);
+        av_opt_set_int       (m_resample_context, "out_channel_layout", chLayout,                       0);
+        av_opt_set_int       (m_resample_context, "in_sample_rate",     m_av_aCodecCtx->sample_rate,    0);
+        av_opt_set_int       (m_resample_context, "out_sample_rate",    m_av_aCodecCtx->sample_rate,    0);
+#ifdef HAVE_LIBAVRESAMPLE
+        av_opt_set_int       (m_resample_context, "in_sample_fmt",      m_av_pFormatCtx->streams[m_av_audioStream]->codec->sample_fmt, 0);
+        av_opt_set_int       (m_resample_context, "out_sample_fmt",     AV_SAMPLE_FMT_S16,              0);
+#elif defined HAVE_LIBSWRESAMPLE
+        av_opt_set_sample_fmt(m_resample_context, "in_sample_fmt",      m_av_pFormatCtx->streams[m_av_audioStream]->codec->sample_fmt, 0);
+        av_opt_set_sample_fmt(m_resample_context, "out_sample_fmt",     AV_SAMPLE_FMT_S16,              0);
+#endif
+
+#ifdef HAVE_LIBAVRESAMPLE
+        avresample_open(m_resample_context);
+#elif defined HAVE_LIBSWRESAMPLE
+        swr_init(m_resample_context);
+#endif
+    }
+#endif
 
     if (!m_soundFormat.isValid()) {
         updateSoundFormat();
@@ -853,7 +944,25 @@ void InternetRadioDecoder::openAVStream(const QString &stream, bool warningsNotE
     m_av_pFormatCtx = avformat_alloc_context();
     m_av_pFormatCtx->probesize = m_maxProbeSize;
 
-    m_av_pFormatCtx->max_analyze_duration = m_maxAnalyzeTime * AV_TIME_BASE;
+    // FIXME: divergence between mpeg.org and libav.org
+    // ffmpeg.org:  current:    max_analyze_duration2
+    //              deprecated: max_analyze_duration
+    //              LIBAVFORMAT_VERSION_INT >= AV_VERSION_INT(55, 43, 100)
+    //              commit: 5482780a3b6ef0a8934cf29aa7e2f1ef7ccb701e
+    // libav.org:   current/master:    max_analyze_duration
+    //              no change in any branch/release, at least up to
+    //              LIBAVFORMAT_VERSION_INT >= AV_VERSION_INT(56, 6, 0)
+    //
+    // As long as libav does not switch to max_analyze_duration2, and as
+    // long as we cannot distinguish libav.org and libffmpeg, we need to
+    // stay with max_analyze_duration
+    m_av_pFormatCtx->max_analyze_duration  = m_maxAnalyzeTime * AV_TIME_BASE;
+
+// #if  LIBAVFORMAT_VERSION_INT >= AV_VERSION_INT(55, 43, 100) // ffmpeg commit 5482780a3b6ef0a8934cf29aa7e2f1ef7ccb701e
+//     m_av_pFormatCtx->max_analyze_duration2 = m_maxAnalyzeTime * AV_TIME_BASE;
+// #else
+//     m_av_pFormatCtx->max_analyze_duration  = m_maxAnalyzeTime * AV_TIME_BASE;
+// #endif
 
     m_av_pFormatCtx_opened = false;
 #ifdef INET_RADIO_STREAM_HANDLING_BY_DECODER_THREAD
@@ -885,7 +994,7 @@ void InternetRadioDecoder::openAVStream(const QString &stream, bool warningsNotE
                 log(ThreadLogging::LogWarning, i18n("cannot open MMS stream %1", stream));
             } else {
                 m_error = true;
-                log(ThreadLogging::LogError, i18n("cannot open MMS  %1", stream));
+                log(ThreadLogging::LogError, i18n("cannot open MMS stream %1", stream));
             }
             closeAVStream();
         } else {
@@ -940,6 +1049,9 @@ void InternetRadioDecoder::updateSoundFormat()
         int  rate = m_av_pFormatCtx->streams[m_av_audioStream]->codec->sample_rate;
         int  ch   = m_av_pFormatCtx->streams[m_av_audioStream]->codec->channels;
         int  fmt  = m_av_pFormatCtx->streams[m_av_audioStream]->codec->sample_fmt;
+#if defined(HAVE_LIBAVRESAMPLE) || defined (HAVE_LIBSWRESAMPLE)
+        fmt       = AV_SAMPLE_FMT_S16;
+#endif
         int  bits     = 0;
         int  issigned = 0;
         bool isplanar = false;
@@ -975,10 +1087,18 @@ void InternetRadioDecoder::updateSoundFormat()
                 issigned = true;
                 isplanar = true;
                 break;
+            case AV_SAMPLE_FMT_FLT:
+            case AV_SAMPLE_FMT_DBL:
+            case AV_SAMPLE_FMT_FLTP:
+            case AV_SAMPLE_FMT_DBLP:
+                m_error = true;
+                log(ThreadLogging::LogError, i18n("Not yet implemented: libav sample format id %1", fmt));
+                closeAVStream();
+                return;
 #endif
             default:
                 m_error = true;
-                log(ThreadLogging::LogError, i18n("Cannot use libav sample format id %1").arg(fmt));
+                log(ThreadLogging::LogError, i18n("Cannot use libav sample format id %1", fmt));
                 closeAVStream();
                 return;
         }
@@ -1015,6 +1135,18 @@ void InternetRadioDecoder::closeAVStream()
     if (m_av_aCodecCtx) {
         avcodec_close(m_av_aCodecCtx);
     }
+#ifdef HAVE_LIBAVRESAMPLE
+    if (m_resample_context) {
+        avresample_close(m_resample_context);
+        avresample_free(&m_resample_context);
+        m_resample_context = NULL;
+    }
+#elif defined HAVE_LIBSWRESAMPLE
+    if (m_resample_context) {
+        swr_free(&m_resample_context);
+        m_resample_context = NULL;
+    }
+#endif
 
     freeAVIOContext();
 
