@@ -45,6 +45,11 @@ extern "C" {
     #include <libavformat/avformat.h>
     #include <libavutil/dict.h>
 #endif
+#ifdef HAVE_LIBAVRESAMPLE
+    #include <libavresample/avresample.h>
+#elif defined(HAVE_LIBSWRESAMPLE)
+    #include <libswresample/swresample.h>
+#endif
 #ifdef HAVE_FFMPEG_OLD
     #include <ffmpeg/avformat.h>
 #endif
@@ -67,7 +72,7 @@ extern "C" {
 
 /*! Enable DEBUGGING: Log Buffer States
  */
-//#define DEBUG_LOG_BUFFER_STATE
+// #define DEBUG_LOG_BUFFER_STATE
 
 /*! Enable DEBUGGING: Do not send PCM data to the audio
  *  interface (fast decoding)
@@ -171,6 +176,11 @@ protected:
 #if  LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(53, 42, 0) // checked: avcodec_decode_audio4 in ffmpeg >= 0.9
     AVFrame              *m_decoded_frame;
 #endif
+#ifdef HAVE_LIBAVRESAMPLE
+    AVAudioResampleContext  *m_resample_context;
+#elif defined HAVE_LIBSWRESAMPLE
+    SwrContext              *m_resample_context;
+#endif
 
 #ifdef INET_RADIO_STREAM_HANDLING_BY_DECODER_THREAD
     bool                  m_is_mms_stream;
