@@ -122,27 +122,24 @@ void LIRCConfiguration::readLIRCConfigurationFile()
 {
     comboPowerOffMode->clear();
     comboPowerOnMode ->clear();
-    comboPowerOffMode->addItem(i18n("<don't care>"), QVariant(""));
-    comboPowerOnMode ->addItem(i18n("<don't care>"), QVariant(""));
+    comboPowerOffMode->addItem(i18n("<do not care>"), QVariant(""));
+    comboPowerOnMode ->addItem(i18n("<do not care>"), QVariant(""));
 
     if (m_LIRC && m_LIRC->getLIRC_fd() >= 0) {
 
         QStringList modes;
 
         QString     lirc_config_file    = edLIRCConfigurationFile->url().path();
-        char       *lirc_cfg_filename_c = lirc_config_file.toUtf8().data();
-        if (lirc_cfg_filename_c) {
-            lirc_cfg_filename_c = strdup(lirc_cfg_filename_c);
-        }
+        QByteArray  lirc_cfg_filename_ba = QFile::encodeName(lirc_config_file);
 
         QFileInfo   lirc_config_file_info(lirc_config_file);
 
         struct lirc_config *cfg = NULL;
 
     //     IErrorLogClient::staticLogDebug(QString("LIRCConfiguration::readLIRCConfigurationFile: lirc config file = >%1<").arg(lirc_config_file));
-    //     IErrorLogClient::staticLogDebug(QString("LIRCConfiguration::readLIRCConfigurationFile: lirc config file(C-String) = >%1<").arg(lirc_cfg_filename_c));
+    //     IErrorLogClient::staticLogDebug(QString("LIRCConfiguration::readLIRCConfigurationFile: lirc config file(C-String) = >%1<").arg(lirc_cfg_filename_ba.constData()));
 
-        if (lirc_config_file_info.isFile() && lirc_config_file_info.exists() && lirc_readconfig (lirc_cfg_filename_c, &cfg, NULL) == 0) {
+        if (lirc_config_file_info.isFile() && lirc_config_file_info.exists() && lirc_readconfig (lirc_cfg_filename_ba.data(), &cfg, NULL) == 0) {
 
             for (lirc_config_entry *e = cfg ? cfg->first : NULL; e; e = e->next) {
                 QString mode = e->mode;
@@ -158,11 +155,6 @@ void LIRCConfiguration::readLIRCConfigurationFile()
                 comboPowerOnMode ->addItem(mode, QVariant(mode));
             }
         }
-
-        if (lirc_cfg_filename_c) {
-            delete lirc_cfg_filename_c;
-            lirc_cfg_filename_c = NULL;
-        }
     }
 }
 
@@ -281,7 +273,7 @@ void LIRCConfiguration::slotRenamingStarted(ListViewItemLirc */*sender*/, int /*
 
 void LIRCConfiguration::slotRenamingStopped(ListViewItemLirc */*sender*/, int /*col*/)
 {
-    m_LabelHints->setText(i18n("Double Click on the entries to change the assignments"));
+    m_LabelHints->setText(i18n("Double click on the entries to change the assignments"));
 }
 
 
