@@ -24,6 +24,7 @@
 #include <QtCore/QSocketNotifier>
 #include <QtCore/QTimer>
 #include <QtCore/QFile>
+#include <QtCore/QDir>
 
 #include <kapplication.h>
 #include <kaboutdata.h>
@@ -53,7 +54,7 @@ PLUGIN_LIBRARY_FUNCTIONS(LircSupport, PROJECT_NAME, i18n("Linux Infrared Control
 
 LircSupport::LircSupport(const QString &instanceID, const QString &name)
     : PluginBase(instanceID, name, i18n("LIRC Plugin")),
-      m_lirc_config_file(QString(getenv("HOME")) + "/" + LIRCRC),
+      m_lirc_config_file(QDir::homePath() + "/" + LIRCRC),
       m_lirc_notify(NULL),
       m_fd_lirc(-1),
       m_lircConfig(NULL),
@@ -80,29 +81,29 @@ LircSupport::~LircSupport()
 
 void LircSupport::LIRC_init_fd()
 {
-    QString dbgStartMsg1 = i18n("initializing kradio lirc plugin");
-    QString dbgStartMsg2 = i18n("warnings/errors about missing sockets don't harm - usually the LIRC daemon is not running in these cases.");
+    QString dbgStartMsg1 = i18n("initializing KRadio LIRC plugin");
+    QString dbgStartMsg2 = i18n("warnings/errors about missing sockets do not harm - usually the LIRC daemon is not running in these cases.");
     logDebug(dbgStartMsg1);
     logDebug(dbgStartMsg2);
-    fprintf (stderr, "%s\n%s\n", dbgStartMsg1.toLocal8Bit().data(), dbgStartMsg2.toLocal8Bit().data());
+    fprintf (stderr, "%s\n%s\n", qPrintable(dbgStartMsg1), qPrintable(dbgStartMsg2));
 
     m_fd_lirc     = lirc_init(LIRCPROG, 1);
 
     if (m_fd_lirc == -1) {
         m_lirc_notify = NULL;
-        QString         warnMsg = i18n("Initializing kradio lirc plugin failed");
+        QString         warnMsg = i18n("Initializing KRadio LIRC plugin failed");
         logWarning      (warnMsg);
         staticLogWarning(warnMsg);
-        fprintf (stderr, "%s\n", warnMsg.toLocal8Bit().data());
+        fprintf (stderr, "%s\n", qPrintable(warnMsg));
     } else {
         m_lirc_notify = new QSocketNotifier(m_fd_lirc, QSocketNotifier::Read, this);
         if (m_lirc_notify)
             QObject::connect(m_lirc_notify, SIGNAL(activated(int)), this, SLOT(slotLIRC(int)));
 
-        QString       dbgMsg = i18n("Initializing kradio lirc plugin successful");
+        QString       dbgMsg = i18n("Initializing KRadio LIRC plugin successful");
         logDebug      (dbgMsg);
         staticLogDebug(dbgMsg);
-        fprintf (stderr, "%s\n", dbgMsg.toLocal8Bit().data());
+        fprintf (stderr, "%s\n", qPrintable(dbgMsg));
     }
 }
 
@@ -113,11 +114,8 @@ void LircSupport::LIRC_init_config()
     m_lircConfig  = 0;
 
     if (m_fd_lirc != -1) {
-        char *lirc_cfg_filename_c = m_lirc_config_file.toUtf8().data();
-        if (lirc_cfg_filename_c) {
-            lirc_cfg_filename_c = strdup(lirc_cfg_filename_c);
-        }
-        if (lirc_readconfig (lirc_cfg_filename_c, &m_lircConfig, NULL) == 0) {
+        QByteArray lirc_cfg_filename_ba = QFile::encodeName(m_lirc_config_file);
+        if (lirc_readconfig (lirc_cfg_filename_ba.data(), &m_lircConfig, NULL) == 0) {
 
             // check config
             lirc_config_entry *found = NULL;
@@ -146,17 +144,13 @@ void LircSupport::LIRC_init_config()
                 }
             }
             if (!found) {
-                logWarning(i18n("There is no entry for kradio in your .lircrc files %1.", m_lirc_config_file));
+                logWarning(i18n("There is no entry for KRadio in your .lircrc files %1.", m_lirc_config_file));
                 logWarning(i18n("Please setup your .lircrc file %1 correctly.",           m_lirc_config_file));
             }
 
         } else {
-            logWarning      (i18n("Initializing kradio lirc plugin failed. Could not read config file %1", m_lirc_config_file));
-            staticLogWarning(i18n("Initializing kradio lirc plugin failed. Could not read config file %1", m_lirc_config_file));
-        }
-        if (lirc_cfg_filename_c) {
-            delete lirc_cfg_filename_c;
-            lirc_cfg_filename_c = NULL;
+            logWarning      (i18n("Initializing KRadio LIRC plugin failed. Could not read config file %1", m_lirc_config_file));
+            staticLogWarning(i18n("Initializing KRadio LIRC plugin failed. Could not read config file %1", m_lirc_config_file));
         }
     }
 }
@@ -191,22 +185,11 @@ void LircSupport::setLIRCConfigurationFile(const QString &fname)
 
 void LircSupport::checkLIRCConfigurationFile(const QString &fname)
 {
-    QFile  lircrc(fname);
-    if (!lircrc.exists()) {
+    if (!QFile::exists(fname)) {
         logWarning(i18n("%1 does not exist. File was created with KRadio's default .lircrc proposal", fname));
         QString default_lircrc_filename = KStandardDirs::locate("data", "kradio4/default-dot-lircrc");
-        QFile   default_lircrc(default_lircrc_filename);
-        default_lircrc.open(QIODevice::ReadOnly);
-        if (!default_lircrc.error()) {
-            lircrc.open(QIODevice::WriteOnly);
-            char *buf = new char [default_lircrc.size() + 1];
-            default_lircrc.read(buf, default_lircrc.size());
-            lircrc.write(buf, default_lircrc.size());
-            lircrc.close();
-            default_lircrc.close();
-            delete buf;
-        } else {
-            logError(i18n("failed to read file %1", default_lircrc_filename));
+        if (!QFile::copy(default_lircrc_filename, fname)) {
+            logError(i18n("Failed to copy %1 to %2", default_lircrc_filename, fname));
         }
     }
 }
@@ -258,7 +241,7 @@ void LircSupport::slotLIRC(int /*socket*/ )
     }
     else {
         // some error has occurred on the socket => close lirc plugin
-        logWarning(i18n("Reading from LIRC socket failed. Disabling LIRC Functions till next start of kradio"));
+        logWarning(i18n("Reading from LIRC socket failed. Disabling LIRC functionalities until the next start of KRadio"));
         delete m_lirc_notify;
         m_lirc_notify = NULL;
     }
@@ -416,7 +399,7 @@ void   LircSupport::restoreState (const KConfigGroup &c)
     PluginBase::restoreState(c);
 
 
-    QString lirc_config_file_default = QString(getenv("HOME")) + "/" LIRCRC;
+    QString lirc_config_file_default = QDir::homePath() + "/" LIRCRC;
 
     m_lirc_config_file               = c.readEntry("lirc-configuration-file", lirc_config_file_default);
 
