@@ -105,6 +105,7 @@ TimeControlConfiguration::TimeControlConfiguration (QWidget *parent)
     QObject::connect(buttonDeleteAlarm,     SIGNAL(clicked()),                   this, SLOT(slotSetDirty()));
     QObject::connect(comboAlarmType,        SIGNAL(activated(int)),              this, SLOT(slotSetDirty()));
     QObject::connect(editSleep,             SIGNAL(valueChanged(int)),           this, SLOT(slotSetDirty()));
+    QObject::connect(cbSuspendOnSleep,      SIGNAL(toggled(bool)),               this, SLOT(slotSetDirty()));
     QObject::connect(editRecordingTemplateFileName,  SIGNAL(textEdited(const QString &)), this, SLOT(slotSetDirty()));
     QObject::connect(editRecordingTemplateID3Title,  SIGNAL(textEdited(const QString &)), this, SLOT(slotSetDirty()));
     QObject::connect(editRecordingTemplateID3Artist, SIGNAL(textEdited(const QString &)), this, SLOT(slotSetDirty()));
@@ -150,7 +151,9 @@ bool TimeControlConfiguration::noticeAlarmsChanged(const AlarmVector &sl)
     for (ciAlarmVector i = alarms.begin(); i != alarms.end(); ++i, ++k) {
         const Alarm &alarm = *i;
         QString      dateString = alarm.nextAlarm(true).toString();
-        dateString += alarm.isEnabled() ? "" : " (disabled)";
+        if (!alarm.isEnabled()) {
+            dateString = i18nc("disabled alarm", "%1 (disabled)", dateString);
+        }
         listAlarms->addItem(dateString);
         QListWidgetItem *item = listAlarms->item(listAlarms->count()-1);
         if (!m_defaultAlarmTextForegroundValid) {
@@ -194,13 +197,15 @@ bool TimeControlConfiguration::noticeCountdownZero()
     return false;
 }
 
-bool TimeControlConfiguration::noticeCountdownSecondsChanged(int n)
+bool TimeControlConfiguration::noticeCountdownSecondsChanged(int n, bool suspendOnSleep)
 {
     editSleep->setValue((int)rint(n / 60));
+    cbSuspendOnSleep->setChecked(suspendOnSleep);
     return false;
 }
 
 
+
 // IRadioClient
 
 bool TimeControlConfiguration::noticePowerChanged(bool /*on*/)
@@ -217,7 +222,7 @@ bool TimeControlConfiguration::noticeStationsChanged(const StationList &sl)
 {
     comboStationSelection->clear();
     stationIDs.clear();
-    comboStationSelection->addItem(i18n("<don't change>"));
+    comboStationSelection->addItem(i18n("<do not change>"));
     stationIDs.push_back(QString::null);
 
     for (StationList::const_iterator i = sl.begin(); i != sl.end(); ++i) {
@@ -327,7 +332,9 @@ void TimeControlConfiguration::slotEnabledChanged( bool b)
         QString          dateString = alarm.nextAlarm(true).toString();
         QListWidgetItem *item       = listAlarms->item(idx);
         alarm.setEnabled(b);
-        dateString += alarm.isEnabled() ? "" : " (disabled)";
+        if (!alarm.isEnabled()) {
+            dateString = i18nc("disabled alarm", "%1 (disabled)", dateString);
+        }
         item->setForeground(!alarm.isEnabled() ? m_disabledAlarmTextForeground : m_enabledAlarmTextForeground);
         item->setText(dateString);
     }
@@ -513,7 +520,7 @@ void TimeControlConfiguration::slotOK()
 {
     if (m_dirty) {
         sendAlarms(alarms);
-        sendCountdownSeconds(editSleep->value() * 60);
+        sendCountdownSeconds(editSleep->value() * 60, cbSuspendOnSleep->isChecked());
         m_dirty = false;
     }
 }
@@ -522,7 +529,7 @@ void TimeControlConfiguration::slotCancel()
 {
     if (m_dirty) {
         noticeAlarmsChanged(queryAlarms());
-        noticeCountdownSecondsChanged(queryCountdownSeconds());
+        noticeCountdownSecondsChanged(queryCountdownSeconds(), querySuspendOnSleep());
         m_dirty = false;
     }
 }
