@@ -49,7 +49,7 @@ public :
     bool noticeCountdownStarted(const QDateTime &end);
     bool noticeCountdownStopped();
     bool noticeCountdownZero();
-    bool noticeCountdownSecondsChanged(int n);
+    bool noticeCountdownSecondsChanged(int n, bool suspendOnSleep);
 
 // IRadioClient
 
